/*************************************************************/
// Copyright (c) 2020 Oracle and/or its affiliates.
/*************************************************************/

// management route table creation
resource "oci_core_route_table" "sbc_mgmt_routetable" {
  compartment_id = var.compartment_ocid
  vcn_id         = oci_core_vcn.sbc_vcn.id
  display_name   = "${var.resource_label}-sbc_mgmt_routetable"

  route_rules {
    destination_type  = var.prohibit_public_ip_management == true ? "SERVICE_CIDR_BLOCK" : "CIDR_BLOCK"
    destination       = var.prohibit_public_ip_management == true ? data.oci_core_services.oci_services.services[0].cidr_block : local.default_ipaddr
    network_entity_id = var.prohibit_public_ip_management == true ? oci_core_service_gateway.sbc_service_gateway[0].id : oci_core_internet_gateway.sbc_internet_gateway[0].id
  }
}

// media route table creation
resource "oci_core_route_table" "sbc_media_routetable" {
  compartment_id = var.compartment_ocid
  vcn_id         = oci_core_vcn.sbc_vcn.id
  display_name   = "${var.resource_label}-sbc_media_routetable"


  dynamic "route_rules" {
    for_each = var.prohibit_public_ip_media == true ? [] : [1]
    content {
      destination       = local.default_ipaddr
      network_entity_id = oci_core_internet_gateway.sbc_internet_gateway[0].id
    }
  }

}

// ha route table 
resource "oci_core_route_table" "sbc_ha_routetable" {
  compartment_id = var.compartment_ocid
  vcn_id         = oci_core_vcn.sbc_vcn.id
  display_name   = "${var.resource_label}-sbc_ha_routetable"

}
