/*************************************************************/
// Copyright (c) 2020 Oracle and/or its affiliates.
/*************************************************************/



// media security list //


resource "oci_core_security_list" "media_security_list" {
  compartment_id = var.compartment_ocid
  vcn_id         = oci_core_vcn.sbc_vcn.id
  display_name   = "${var.resource_label}-media_security_list"

  egress_security_rules {
    destination = local.default_ipaddr
    protocol    = local.all_protocol
  }

  dynamic "ingress_security_rules" {
    for_each = var.media_enable_tcp == true ? [1] : []
    content {
      protocol = local.tcp_protocol
      source   = local.default_ipaddr
      tcp_options {
        max = var.tcp_port_range_end
        min = var.tcp_port_range_start
      }
    }
  }

  dynamic "ingress_security_rules" {
    for_each = var.media_enable_udp == true ? [1] : []
    content {
      protocol = local.udp_protocol
      source   = local.default_ipaddr
      udp_options {
        max = var.udp_port_range_end
        min = var.udp_port_range_start
      }
    }

  }
  dynamic "ingress_security_rules" {
    for_each = var.media_enable_icmp == true ? [1] : []
    content {
      protocol = local.icmp_protocol
      source   = local.default_ipaddr
    }

  }
}

// management security list //

resource "oci_core_security_list" "sbc_mgmt_security_list" {
  compartment_id = var.compartment_ocid
  vcn_id         = oci_core_vcn.sbc_vcn.id
  display_name   = "${var.resource_label}-sbc_mgmt_security_list_tf"

  egress_security_rules {
    destination = local.default_ipaddr
    protocol    = local.all_protocol
  }

  dynamic "ingress_security_rules" {
    for_each = var.management_enable_http_https == true ? [1] : []
    content {
      protocol = local.tcp_protocol
      source   = local.default_ipaddr


      tcp_options {
        max = 443
        min = 443
      }
    }
  }


  dynamic "ingress_security_rules" {
    for_each = var.management_enable_http_https == true ? [1] : []
    content {
       protocol = local.tcp_protocol
       source   = local.default_ipaddr

      tcp_options {
        max = 80
        min = 80
      }
    }
  }
  dynamic "ingress_security_rules" {
    for_each = var.management_enable_ssh == true ? [1] : []
    content {
      protocol = local.tcp_protocol
      source   = local.default_ipaddr

      tcp_options {
        max = 22
        min = 22
      }
    }
  }

  dynamic "ingress_security_rules" {
    for_each = var.management_enable_ftp == true ? [1] : []
    content {
      protocol = local.tcp_protocol
      source   = local.default_ipaddr

      tcp_options {
        max = 21
        min = 20
      }
    }
  }

  dynamic "ingress_security_rules" {
    for_each = var.management_enable_icmp == true ? [1] : []
    content {
      protocol = local.icmp_protocol
      source   = local.default_ipaddr
    }

  }

  ingress_security_rules {
    protocol = local.all_protocol
    source   = var.vcn_cidr
  }


}

// ha security list //

resource "oci_core_security_list" "ha_security_list" {
  compartment_id = var.compartment_ocid
  vcn_id         = oci_core_vcn.sbc_vcn.id
  display_name   = "${var.resource_label}-ha_security_list"

  egress_security_rules {
    destination = var.vcn_cidr
    protocol    = local.all_protocol
  }

  ingress_security_rules {
    protocol = local.all_protocol
    source   = var.subnet_cidr_wancom_1
  }

  ingress_security_rules {
    protocol = local.all_protocol
    source   = var.subnet_cidr_wancom_2
  }
}
 
